@@ -1,5 +1,5 @@
 package File::Dir::Dumper::Scanner;
-$File::Dir::Dumper::Scanner::VERSION = '0.6.3';
+$File::Dir::Dumper::Scanner::VERSION = '0.6.4';
 use warnings;
 use strict;
 use autodie;
@@ -267,6 +267,12 @@ sub _calc_file_or_dir_token
 
     my @stat = stat( $result->path() );
 
+    if ( not @stat )
+    {
+        Carp::confess(
+            "Could not successfully stat <<@{[$result->path()]}>> - $!");
+    }
+
     return {
         filename => $result->full_components()->[-1],
         depth    => scalar( @{ $result->full_components() } ),
@@ -335,7 +341,7 @@ hash-refs
 
 =head1 VERSION
 
-version 0.6.3
+version 0.6.4
 
 =head1 SYNOPSIS
 
